pub struct ConsensusInstance { /* private fields */ }Implementations
Sourceimpl ConsensusInstance
impl ConsensusInstance
pub fn new(session_lock: SessionLock, consensus: DynConsensus) -> Self
Sourcepub async fn session_blocking(&self) -> ConsensusSessionBlocking<'_>
pub async fn session_blocking(&self) -> ConsensusSessionBlocking<'_>
Returns a blocking session to be used in non async environments.
Users would usually need to call something like futures::executor::block_on in order
to acquire the session, but we prefer leaving this decision to the caller
Sourcepub fn unguarded_session_blocking(&self) -> ConsensusSessionBlocking<'static>
pub fn unguarded_session_blocking(&self) -> ConsensusSessionBlocking<'static>
Returns an unguarded blocking consensus session. There’s no guarantee that data will not be pruned between
two sequential consensus calls. This session doesn’t hold the consensus pruning lock, so it should
be preferred upon session_blocking() when data consistency is not important.
Sourcepub async fn session(&self) -> ConsensusSessionOwned
pub async fn session(&self) -> ConsensusSessionOwned
Returns a consensus session for accessing consensus operations in a bulk. The user can safely assume
that consensus state is consistent between operations, that is, no pruning was performed between the calls.
The returned object is an owned consensus session type which can be cloned and shared across threads.
The sharing ability is useful for spawning blocking operations on a different thread using the same
session object, see ConsensusSessionOwned::spawn_blocking(). The caller is responsible to make sure
that the overall lifetime of this session is not too long (~2 seconds max)
Sourcepub fn unguarded_session(&self) -> ConsensusSessionOwned
pub fn unguarded_session(&self) -> ConsensusSessionOwned
Returns an unguarded consensus session. There’s no guarantee that data will not be pruned between
two sequential consensus calls. This session doesn’t hold the consensus pruning lock, so it should
be preferred upon session() when data consistency is not important.